"use strict";
/*******************************************************************************
 * Copyright (c) 2018, 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const CommandUtil_1 = require("./CommandUtil");
const Logger_1 = require("../Logger");
const Commands_1 = require("../constants/Commands");
const MCUtil = require("../MCUtil");
const Requester_1 = require("../microclimate/project/Requester");
const langToPathMap = new Map();
langToPathMap.set("java", "javametrics-dash");
langToPathMap.set("nodejs", "appmetrics-dash");
langToPathMap.set("swift", "swiftmetrics-dash");
function openAppMonitorCmd(project) {
    return __awaiter(this, void 0, void 0, function* () {
        // Log.d("openAppMonitorCmd invoked");
        if (project == null) {
            const selected = yield CommandUtil_1.promptForProject();
            if (selected == null) {
                Logger_1.default.d("User cancelled prompt for resource");
                // user cancelled
                return;
            }
            project = selected;
        }
        try {
            const appMetricsPath = langToPathMap.get(project.type.language);
            const supported = appMetricsPath != null && (yield Requester_1.default.areMetricsAvailable(project));
            // const supported = appMetricsPath != null;
            Logger_1.default.d(`${project.name} supports metrics ? ${supported}`);
            if (!supported) {
                vscode.window.showWarningMessage(`${project.name} does not support application metrics.`);
                return;
            }
            if (project.appBaseUrl == null) {
                vscode.window.showWarningMessage(`Cannot open application monitor - ${project.name} is not currently running.`);
                return;
            }
            let monitorPageUrlStr = project.appBaseUrl.toString();
            if (!monitorPageUrlStr.endsWith("/")) {
                monitorPageUrlStr += "/";
            }
            monitorPageUrlStr = monitorPageUrlStr + appMetricsPath;
            Logger_1.default.d("Open monitor at " + monitorPageUrlStr);
            vscode.commands.executeCommand(Commands_1.default.VSC_OPEN, vscode.Uri.parse(monitorPageUrlStr));
        }
        catch (err) {
            vscode.window.showErrorMessage(MCUtil.errToString(err));
        }
    });
}
exports.default = openAppMonitorCmd;
//# sourceMappingURL=OpenAppMonitor.js.map