"use strict";
/*******************************************************************************
 * Copyright (c) 2018, 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
// non-nls-file
/**
 *  "Regular" endpoints, eg "localhost:9090/api/v1/environment"
 */
var MCEndpoints;
(function (MCEndpoints) {
    MCEndpoints["ENVIRONMENT"] = "api/v1/environment";
    MCEndpoints["TEMPLATES"] = "api/v1/templates";
    MCEndpoints["PROJECTS"] = "api/v1/projects";
    MCEndpoints["CREATE_FROM_TEMPLATE"] = "api/v1/projects/";
    MCEndpoints["PREBIND_VALIDATE"] = "api/v1/validate";
    MCEndpoints["BIND"] = "api/v1/projects/bind";
})(MCEndpoints = exports.MCEndpoints || (exports.MCEndpoints = {}));
/**
 * Project endpoints, eg "localhost:9090/api/v1/project/81eba580-0aea-11e9-b530-67b2995d0cd9/restart"
 */
var ProjectEndpoints;
(function (ProjectEndpoints) {
    ProjectEndpoints["RESTART_ACTION"] = "restart";
    ProjectEndpoints["BUILD_ACTION"] = "build";
    ProjectEndpoints["PROPERTES"] = "properties";
    ProjectEndpoints["LOGS"] = "logs";
    ProjectEndpoints["METRICS_STATUS"] = "metrics/status";
    ProjectEndpoints["OPEN"] = "open";
    ProjectEndpoints["CLOSE"] = "close";
    ProjectEndpoints["UNBIND"] = "unbind";
})(ProjectEndpoints = exports.ProjectEndpoints || (exports.ProjectEndpoints = {}));
/**
 * Functions for resolving Portal endpoints
 */
var EndpointUtil;
(function (EndpointUtil) {
    function isProjectEndpoint(endpoint) {
        return Object.values(ProjectEndpoints).includes(endpoint);
    }
    EndpointUtil.isProjectEndpoint = isProjectEndpoint;
    function resolveMCEndpoint(connection, endpoint) {
        return connection.mcUri.toString().concat(endpoint);
    }
    EndpointUtil.resolveMCEndpoint = resolveMCEndpoint;
    function resolveProjectEndpoint(connection, projectID, endpoint) {
        return connection.mcUri.toString().concat(`${MCEndpoints.PROJECTS}/${projectID}/${endpoint}`);
    }
    EndpointUtil.resolveProjectEndpoint = resolveProjectEndpoint;
    function getEnablementAction(enable) {
        return enable ? ProjectEndpoints.OPEN : ProjectEndpoints.CLOSE;
    }
    EndpointUtil.getEnablementAction = getEnablementAction;
    function getPerformanceDashboard(project) {
        // return value looks like http://localhost:9090/performance/charts?project=bacd4760-70ce-11e9-af94-d39edf21b705
        const query = `project=${project.id}`;
        return project.connection.mcUri.with({ path: "/performance/charts", query });
    }
    EndpointUtil.getPerformanceDashboard = getPerformanceDashboard;
})(EndpointUtil = exports.EndpointUtil || (exports.EndpointUtil = {}));
exports.default = EndpointUtil;
//# sourceMappingURL=Endpoints.js.map