"use strict";
/*******************************************************************************
 * Copyright (c) 2018, 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const Connection_1 = require("./Connection");
const ActivateConnectionCmd_1 = require("../../command/ActivateConnectionCmd");
const Logger_1 = require("../../Logger");
class ConnectionManager {
    constructor() {
        this._connections = [];
        this.listeners = [];
        /**
         * Call this whenever a connection is added, removed, or changed.
         * Pass the item that changed (Connection or Project) or undefined for the tree's root.
         */
        this.onChange = (changed) => {
            // Log.d(`There was a change, notifying ${this.listeners.length} listeners`);
            this.listeners.forEach((cb) => cb(changed));
        };
        this.initPromise = ActivateConnectionCmd_1.default().then(() => Promise.resolve());
    }
    static get instance() {
        return ConnectionManager._instance || (ConnectionManager._instance = new this());
    }
    dispose() {
        return __awaiter(this, void 0, void 0, function* () {
            return Promise.all(this.connections.map((conn) => conn.dispose()))
                .then(() => Promise.resolve());
        });
    }
    get connections() {
        return this._connections;
    }
    // public get allProjects(): Promise<Project[]> {
    //     return this.connections.reduce(async (allProjects: Promise<Project[]>, connection: Connection): Promise<Project[]> => {
    //         const projects = await connection.getProjects();
    //         return (await allProjects).concat(projects);
    //     }, Promise.resolve([]));
    // }
    addConnection(uri, host, mcVersion, socketNS, workspace) {
        return __awaiter(this, void 0, void 0, function* () {
            const existing = this.getExisting(uri);
            if (existing != null) {
                // const alreadyExists = Translator.t(StringNamespaces.DEFAULT, "connectionAlreadyExists", { uri });
                // Log.i(alreadyExists);
                return existing;
            }
            // all validation that this connection is good must be done by this point
            const newConnection = new Connection_1.default(uri, host, mcVersion, socketNS, workspace);
            Logger_1.default.i("New Connection @ " + uri);
            this._connections.push(newConnection);
            // ConnectionManager.saveConnections();
            // pass undefined here to refresh the tree from its root
            this.onChange(undefined);
            return newConnection;
        });
    }
    // public async removeConnection(connection: Connection): Promise<boolean> {
    //     const indexToRemove = this.connections.indexOf(connection);
    //     if (indexToRemove === -1) {
    //         Log.e(`Request to remove connection ${connection} but it doesn't exist!`);
    //         return false;
    //     }
    //     connection.dispose();
    //     this.connections.splice(indexToRemove, 1);
    //     Log.i("Removed connection", connection);
    //     // ConnectionManager.saveConnections();
    //     this.onChange(undefined);
    //     return true;
    // }
    /**
     * To be called on connection reconnect. Hits the environment endpoint at the given existing Connection's URI,
     * and returns if the response data matches the existing Connection.
     *
     * The given Connection will be destroyed if the data does not match (ie, this function returns `false`),
     * and thus must not do anything further.
     *
     */
    // public async verifyReconnect(connection: Connection): Promise<boolean> {
    //     Log.d("Verifying reconnect at " + connection.mcUri);
    //     let tries = 0;
    //     let newEnvData: MCEnvironment.IMCEnvData | undefined;
    //     // Sometimes this can execute before Portal is ready, resulting in a 404.
    //     while (newEnvData == null && tries < 10) {
    //         tries++;
    //         try {
    //             newEnvData = await MCEnvironment.getEnvData(connection.mcUri);
    //         }
    //         catch (err) {
    //             // wait briefly before trying again
    //             await new Promise( (resolve) => setTimeout(resolve, 250));
    //         }
    //     }
    //     if (newEnvData == null) {
    //         // I don't think this will ever happen
    //         Log.e("Couldn't get a good response from environment endpoint " + connection.mcUri);
    //         vscode.window.showErrorMessage(Translator.t(StringNamespaces.DEFAULT, "failedToReconnect", { uri: connection.mcUri }));
    //         await this.removeConnection(connection);
    //         return false;
    //     }
    //     if (MCEnvironment.envMatches(connection, newEnvData)) {
    //         // it's the same instance, so we don't have to do anything
    //         return true;
    //     }
    //     else {
    //         Log.d("Instance changed on reconnect!");
    //         await this.removeConnection(connection);
    //         // will also add the new Connection to this ConnectionManager
    //         // const newConnection = await activateConnectionCmd(MCUtil.getConnInfoFrom(connection.mcUri));
    //         const newConnection = await activateConnectionCmd();
    //         if (newConnection == null) {
    //             // should never happen
    //             Log.e("Failed to create new connection after verifyReconnect failure");
    //             return false;
    //         }
    //         const msg = Translator.t(StringNamespaces.DEFAULT, "versionChanged",
    //             { uri: connection.mcUri, oldVersion: connection.versionStr, newVersion: newConnection.versionStr }
    //         );
    //         vscode.window.showInformationMessage(msg);
    //         return false;
    //     }
    // }
    getExisting(uri) {
        return this._connections.find((conn) => {
            return conn.mcUri.toString() === uri.toString();
        });
    }
    // private static loadConnections(): MCUtil.IConnectionInfo[] {
    //     const globalState = global.extGlobalState as vscode.Memento;
    //     const loaded = globalState.get<MCUtil.IConnectionInfo[]>(Settings.CONNECTIONS_KEY) || [];
    //     return loaded;
    // }
    // private static async saveConnections(): Promise<void> {
    //     // We save IConnectionInfo objects since they are simpler and more readable than VSCode URIs.
    //     // This will likely change with ICP support since we would then have to store protocol too.
    //     const connectionInfos: MCUtil.IConnectionInfo[] = ConnectionManager.instance.connections
    //         .map( (connection) => MCUtil.getConnInfoFrom(connection.mcUri));
    //     Log.i("Saving connections", connectionInfos);
    //     try {
    //         const globalState = global.extGlobalState as vscode.Memento;
    //         // connectionInfos must not contain cyclic references (ie, JSON.stringify succeeds)
    //         await globalState.update(Settings.CONNECTIONS_KEY, connectionInfos);
    //     }
    //     catch (err) {
    //         const msg = Translator.t(StringNamespaces.DEFAULT, "errorSavingConnections", { err: err.toString() });
    //         Log.e(msg, err);
    //         vscode.window.showErrorMessage(msg);
    //     }
    // }
    /**
     * Pass this a function to call whenever a connection is added, removed, or changed,
     * eg to trigger a tree update in the UI.
     * Test-friendly.
     */
    addOnChangeListener(callback) {
        Logger_1.default.i("Adding onChangeListener " + callback.name);
        this.listeners.push(callback);
    }
}
exports.default = ConnectionManager;
//# sourceMappingURL=ConnectionManager.js.map