"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*******************************************************************************
 * Copyright (c) 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
const vscode = require("vscode");
const translator_1 = require("../../../constants/strings/translator");
const StringNamespaces_1 = require("../../../constants/strings/StringNamespaces");
const STRING_NS = StringNamespaces_1.default.LOGS;
class MCLog {
    constructor(projectName, 
    // MUST match the logName provided in the log-update events
    logName, logPath) {
        this.logName = logName;
        this.logPath = logPath;
        this.displayName = `${projectName} - ${this.logName}`;
        this.label = this.displayName;
        // this.detail = logPath;
        // this.description = `(${this.logType} log)`;
        // Log.d(`Initialized log ${this.displayName} internal name ${this.logName} from ${}`);
    }
    onNewLogs(reset, logs) {
        if (!this.output) {
            return;
        }
        if (reset) {
            // Log.d("Reset " + this.displayName);
            this.output.clear();
        }
        // Log.d(`${this.displayName} appending length ${logs.length}`);
        this.output.append(logs);
    }
    get isOpen() {
        return this.output != null;
    }
    // quickPickItem
    get picked() {
        return this.isOpen;
    }
    removeOutput() {
        // Log.d("Hide log " + this.displayName);
        if (this.output) {
            this.output.dispose();
            this.output = undefined;
        }
    }
    showOutput() {
        // Log.d("Show log " + this.displayName);
        if (!this.output) {
            // Log.d("Creating output for log " + this.displayName);
            this.output = vscode.window.createOutputChannel(this.displayName);
            this.output.show();
            this.output.appendLine(translator_1.default.t(STRING_NS, "waitingForLogs"));
        }
    }
    onDisconnectOrDisable(disconnect) {
        if (this.output) {
            let notUpdatingReason;
            if (disconnect) {
                notUpdatingReason = translator_1.default.t(STRING_NS, "notUpdatingReasonDisconnect");
            }
            else {
                notUpdatingReason = translator_1.default.t(STRING_NS, "notUpdatingReasonDisabled");
            }
            const msg = "*".repeat(8) + translator_1.default.t(STRING_NS, "logNoLongerUpdating", { reason: notUpdatingReason });
            this.output.appendLine(msg);
        }
    }
    destroy() {
        this.removeOutput();
    }
}
exports.default = MCLog;
//# sourceMappingURL=MCLog.js.map